package de.intevation.flys.artifacts.model;

import de.intevation.artifacts.Artifact;
import de.intevation.artifacts.CallContext;

import de.intevation.artifactdatabase.state.DefaultFacet;

import de.intevation.flys.artifacts.WQKmsInterpolArtifact;

/**
 * Facet to show W|Q Values.
 */
public class WQFacet
extends      DefaultFacet
implements   FacetTypes {

    /** Trivial Constructor. */
    public WQFacet(String description) {
        this(STATIC_WQ, description);
    }


    /**
     * A Facet with WQ data.
     */
    public WQFacet(String name, String description) {
        this.name        = name;
        this.description = description;
        this.index       = 0;
    }


    /**
     * Returns the data this facet provides at km given in context.
     *
     * @param artifact the owner artifact.
     * @param context  the CallContext.
     *
     * @return the data.
     */
    @Override
    public Object getData(Artifact artifact, CallContext context) {
        WQKmsInterpolArtifact interpolData =
            (WQKmsInterpolArtifact) artifact;
        Double currentKm = (Double)context.getContextValue("currentKm");
        return interpolData.getWQAtKm(currentKm);
    }


    /**
     * Create a deep copy of this Facet.
     * @return a deep copy.
     */
    @Override
    public WQKmsFacet deepCopy() {
        WQKmsFacet copy = new WQKmsFacet(description);
        copy.set(this);
        return copy;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
